(self.webpackJsonp=self.webpackJsonp||[]).push([[90],{167:function(e,s,n){"use strict";n.r(s);var a=n(4),b=n(31),l=n(5);l.b.Element=b.a,l.b.html=a.a,window.Polymer=l.b}}]);
//# sourceMappingURL=chunk.b23b29e0ac8c192c0c73.js.map