(self.webpackJsonp=self.webpackJsonp||[]).push([[34],{784:function(e,r,n){"use strict";n.r(r),n.d(r,"codeMirror",function(){return c}),n.d(r,"codeMirrorCss",function(){return i});var s=n(498),o=n.n(s),t=n(698),a=(n(699),n(700),n(12));o.a.commands.save=(e=>{Object(a.a)(e.getWrapperElement(),"editor-save")});const c=o.a,i=t.a}}]);
//# sourceMappingURL=chunk.cc97140706f89c84b91c.js.map